/*
 * CDDL HEADER START
 *
 * The contents of this file are subject to the terms of the
 * Common Development and Distribution License (the "License").
 * You may not use this file except in compliance with the License.
 *
 * You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE
 * or http://www.opensolaris.org/os/licensing.
 * See the License for the specific language governing permissions
 * and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL HEADER in each
 * file and include the License file at usr/src/OPENSOLARIS.LICENSE.
 * If applicable, add the following below this CDDL HEADER, with the
 * fields enclosed by brackets "[]" replaced with your own identifying
 * information: Portions Copyright [yyyy] [name of copyright owner]
 *
 * CDDL HEADER END
 */
/*
 * Copyright 2012, Daniil Lunev. All rights reserved.
 */

#define SEPARATOR "="

typedef struct menu_entry menu_entry;
typedef struct menu_list menu_list;
typedef enum cmd_id cmd_id;

struct menu_entry {
	char entry_name[MAX_STRING_SIZE];
	char pool_label[MAX_STRING_SIZE];
	char pool_uuid[MAX_STRING_SIZE];
	char dataset[MAX_STRING_SIZE];
	char kernel[MAX_STRING_SIZE];
	char kernel_opts[MAX_STRING_SIZE];
	unsigned int modules_amount;
	char ** modules;
};

extern char default_entry[MAX_STRING_SIZE];
extern char timeout[MAX_STRING_SIZE];
extern char serial[MAX_STRING_SIZE];
extern char terminal[MAX_STRING_SIZE];

struct menu_list {
	unsigned int entry_number;
	menu_entry entry;
	menu_list * next;
};

enum cmd_id {
	CMD_ENTRY_NAME,
	CMD_POOL_LABEL,
	CMD_POOL_UUID,
	CMD_DATA_SET,
	CMD_KERNEL_PATH,
	CMD_KERNEL_OPTIONS,
	CMD_BA_PATH,
	CMD_DEFAULT,
	CMD_TIMEOUT,
	CMD_SERIAL,
	CMD_TERMINAL,
	CMD_UNKNOWN
};

extern const char * cmd_list[];

void
free_menu (menu_list ** menu);

menu_list *
parse_file (const char * file_name, int * entries_amount);

void
list_menu (menu_list * menu);

menu_list *
add_entry (menu_list ** menu, menu_list * entry);

menu_list *
clone_entry (menu_list  *entry);

int
delete_entry (menu_list ** menu, menu_list * del);

menu_list *
find_entry (menu_list * menu, menu_list * find);

menu_list *
enable_hyper (menu_list * entry);

menu_list *
disable_hyper (menu_list * entry);

menu_list *
get_entry_by_number (menu_list * menu, int number);
